@@ -1,19 +1,7 @@
-# Copyright (C) 2023 Greenbone AG
+# SPDX-FileCopyrightText: 2023-2024 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # pylint: disable=line-too-long
 # ruff: noqa: E501
@@ -47,6 +35,7 @@ from greenbone.feed.sync.config import (
     DEFAULT_SCAP_DATA_PATH,
     DEFAULT_SCAP_DATA_URL_PATH,
     DEFAULT_USER,
+    DEFAULT_VERSION,
     Config,
     EnterpriseSettings,
 )
@@ -264,7 +253,7 @@ destination-prefix = "/opt/lib/"
         self.assertEqual(values["destination-prefix"], Path("/opt/lib"))
         self.assertEqual(
             values["gvmd-data-destination"],
-            Path("/opt/lib/gvm/data-objects/gvmd/22.04"),
+            Path(f"/opt/lib/gvm/data-objects/gvmd/{DEFAULT_VERSION}"),
         )
         self.assertEqual(values["notus-destination"], Path("/opt/lib/notus"))
         self.assertEqual(
@@ -278,15 +267,21 @@ destination-prefix = "/opt/lib/"
         )
         self.assertEqual(
             values["report-formats-destination"],
-            Path("/opt/lib/gvm/data-objects/gvmd/22.04/report-formats"),
+            Path(
+                f"/opt/lib/gvm/data-objects/gvmd/{DEFAULT_VERSION}/report-formats"
+            ),
         )
         self.assertEqual(
             values["scan-configs-destination"],
-            Path("/opt/lib/gvm/data-objects/gvmd/22.04/scan-configs"),
+            Path(
+                f"/opt/lib/gvm/data-objects/gvmd/{DEFAULT_VERSION}/scan-configs"
+            ),
         )
         self.assertEqual(
             values["port-lists-destination"],
-            Path("/opt/lib/gvm/data-objects/gvmd/22.04/port-lists"),
+            Path(
+                f"/opt/lib/gvm/data-objects/gvmd/{DEFAULT_VERSION}/port-lists"
+            ),
         )
         self.assertEqual(
             values["openvas-lock-file"],
@@ -308,35 +303,35 @@ feed-url = "rsync://foo.bar"
         self.assertEqual(values["feed-url"], "rsync://foo.bar")
         self.assertEqual(
             values["gvmd-data-url"],
-            "rsync://foo.bar/data-feed/22.04/",
+            f"rsync://foo.bar/data-feed/{DEFAULT_VERSION}/",
         )
         self.assertEqual(
             values["notus-url"],
-            "rsync://foo.bar/vulnerability-feed/22.04/vt-data/notus/",
+            f"rsync://foo.bar/vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/",
         )
         self.assertEqual(
             values["nasl-url"],
-            "rsync://foo.bar/vulnerability-feed/22.04/vt-data/nasl/",
+            f"rsync://foo.bar/vulnerability-feed/{DEFAULT_VERSION}/vt-data/nasl/",
         )
         self.assertEqual(
             values["scap-data-url"],
-            "rsync://foo.bar/vulnerability-feed/22.04/scap-data/",
+            f"rsync://foo.bar/vulnerability-feed/{DEFAULT_VERSION}/scap-data/",
         )
         self.assertEqual(
             values["cert-data-url"],
-            "rsync://foo.bar/vulnerability-feed/22.04/cert-data/",
+            f"rsync://foo.bar/vulnerability-feed/{DEFAULT_VERSION}/cert-data/",
         )
         self.assertEqual(
             values["report-formats-url"],
-            "rsync://foo.bar/data-feed/22.04/report-formats/",
+            f"rsync://foo.bar/data-feed/{DEFAULT_VERSION}/report-formats/",
         )
         self.assertEqual(
             values["scan-configs-url"],
-            "rsync://foo.bar/data-feed/22.04/scan-configs/",
+            f"rsync://foo.bar/data-feed/{DEFAULT_VERSION}/scan-configs/",
         )
         self.assertEqual(
             values["port-lists-url"],
-            "rsync://foo.bar/data-feed/22.04/port-lists/",
+            f"rsync://foo.bar/data-feed/{DEFAULT_VERSION}/port-lists/",
         )
 
     @patch.dict(
