@@ -1,19 +1,7 @@
-# Copyright (C) 2023 Greenbone AG
+# SPDX-FileCopyrightText: 2023-2024 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
 import unittest
@@ -22,6 +10,7 @@ from unittest.mock import MagicMock, call, patch
 
 from pontos.testing import temp_directory
 
+from greenbone.feed.sync.config import DEFAULT_VERSION
 from greenbone.feed.sync.errors import GreenboneFeedSyncError, RsyncError
 from greenbone.feed.sync.main import (
     Sync,
@@ -82,17 +71,21 @@ class FeedSyncTestCase(unittest.IsolatedAsyncioTestCase):
         console = MagicMock()
         rsync_mock_instance = rsync_mock.return_value
 
-        with temp_directory() as temp_dir, patch.dict(
-            "os.environ",
-            {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
-        ), patch.object(
-            sys,
-            "argv",
-            [
-                "greenbone-feed-sync",
-                "--type",
-                "nvt",
-            ],
+        with (
+            temp_directory() as temp_dir,
+            patch.dict(
+                "os.environ",
+                {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
+            ),
+            patch.object(
+                sys,
+                "argv",
+                [
+                    "greenbone-feed-sync",
+                    "--type",
+                    "nvt",
+                ],
+            ),
         ):
             ret = await feed_sync(console=console, error_console=console)
             self.assertEqual(ret, 0)
@@ -120,12 +113,12 @@ class FeedSyncTestCase(unittest.IsolatedAsyncioTestCase):
             [
                 call(
                     url="rsync://feed.community.greenbone.net/community/"
-                    "vulnerability-feed/22.04/vt-data/notus/",
+                    f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/",
                     destination=temp_dir / "notus",
                 ),
                 call(
                     url="rsync://feed.community.greenbone.net/community/"
-                    "vulnerability-feed/22.04/vt-data/nasl/",
+                    f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/nasl/",
                     destination=temp_dir / "openvas/plugins",
                 ),
             ]
@@ -136,17 +129,21 @@ class FeedSyncTestCase(unittest.IsolatedAsyncioTestCase):
         console = MagicMock()
         rsync_mock_instance = rsync_mock.return_value
 
-        with temp_directory() as temp_dir, patch.dict(
-            "os.environ",
-            {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
-        ), patch.object(
-            sys,
-            "argv",
-            [
-                "greenbone-feed-sync",
-                "--type",
-                "nvt",
-            ],
+        with (
+            temp_directory() as temp_dir,
+            patch.dict(
+                "os.environ",
+                {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
+            ),
+            patch.object(
+                sys,
+                "argv",
+                [
+                    "greenbone-feed-sync",
+                    "--type",
+                    "nvt",
+                ],
+            ),
         ):
             ret = await feed_sync(console=console, error_console=console)
             self.assertEqual(ret, 0)
@@ -177,12 +174,12 @@ class FeedSyncTestCase(unittest.IsolatedAsyncioTestCase):
                 [
                     call(
                         url="rsync://feed.community.greenbone.net/community/"
-                        "vulnerability-feed/22.04/vt-data/notus/",
+                        f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/",
                         destination=temp_dir / "notus",
                     ),
                     call(
                         url="rsync://feed.community.greenbone.net/community/"
-                        "vulnerability-feed/22.04/vt-data/nasl/",
+                        f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/nasl/",
                         destination=temp_dir / "openvas/plugins",
                     ),
                 ]
@@ -193,13 +190,17 @@ class FeedSyncTestCase(unittest.IsolatedAsyncioTestCase):
         console = MagicMock()
         rsync_mock_instance = rsync_mock.return_value
 
-        with temp_directory() as temp_dir, patch.dict(
-            "os.environ",
-            {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
-        ), patch.object(
-            sys,
-            "argv",
-            ["greenbone-feed-sync", "--type", "nvt", "-vvv"],
+        with (
+            temp_directory() as temp_dir,
+            patch.dict(
+                "os.environ",
+                {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
+            ),
+            patch.object(
+                sys,
+                "argv",
+                ["greenbone-feed-sync", "--type", "nvt", "-vvv"],
+            ),
         ):
             ret = await feed_sync(console=console, error_console=console)
             self.assertEqual(ret, 0)
@@ -222,15 +223,15 @@ class FeedSyncTestCase(unittest.IsolatedAsyncioTestCase):
                     call(
                         "Downloading Notus files from "
                         "rsync://feed.community.greenbone.net/community/"
-                        "vulnerability-feed/22.04/vt-data/notus/ to "
-                        f"{temp_dir}/notus"
+                        f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/ "
+                        f"to {temp_dir}/notus"
                     ),
                     call(),
                     call(
                         "Downloading NASL files from "
                         "rsync://feed.community.greenbone.net/community/"
-                        "vulnerability-feed/22.04/vt-data/nasl/ to "
-                        f"{temp_dir}/openvas/plugins"
+                        f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/nasl/ "
+                        f"to {temp_dir}/openvas/plugins"
                     ),
                     call(),
                     call(
@@ -244,12 +245,12 @@ class FeedSyncTestCase(unittest.IsolatedAsyncioTestCase):
                 [
                     call(
                         url="rsync://feed.community.greenbone.net/community/"
-                        "vulnerability-feed/22.04/vt-data/notus/",
+                        f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/",
                         destination=temp_dir / "notus",
                     ),
                     call(
                         url="rsync://feed.community.greenbone.net/community/"
-                        "vulnerability-feed/22.04/vt-data/nasl/",
+                        f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/nasl/",
                         destination=temp_dir / "openvas/plugins",
                     ),
                 ]
@@ -260,13 +261,17 @@ class FeedSyncTestCase(unittest.IsolatedAsyncioTestCase):
         console = MagicMock()
         rsync_mock_instance = rsync_mock.return_value
 
-        with temp_directory() as temp_dir, patch.dict(
-            "os.environ",
-            {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
-        ), patch.object(
-            sys,
-            "argv",
-            ["greenbone-feed-sync", "--type", "nvt", "--quiet"],
+        with (
+            temp_directory() as temp_dir,
+            patch.dict(
+                "os.environ",
+                {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
+            ),
+            patch.object(
+                sys,
+                "argv",
+                ["greenbone-feed-sync", "--type", "nvt", "--quiet"],
+            ),
         ):
             ret = await feed_sync(console=console, error_console=console)
             self.assertEqual(ret, 0)
@@ -283,12 +288,12 @@ class FeedSyncTestCase(unittest.IsolatedAsyncioTestCase):
                 [
                     call(
                         url="rsync://feed.community.greenbone.net/community/"
-                        "vulnerability-feed/22.04/vt-data/notus/",
+                        f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/",
                         destination=temp_dir / "notus",
                     ),
                     call(
                         url="rsync://feed.community.greenbone.net/community/"
-                        "vulnerability-feed/22.04/vt-data/nasl/",
+                        f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/nasl/",
                         destination=temp_dir / "openvas/plugins",
                     ),
                 ]
@@ -302,13 +307,17 @@ class FeedSyncTestCase(unittest.IsolatedAsyncioTestCase):
             2, [], b"An rsync error"
         )
 
-        with temp_directory() as temp_dir, patch.dict(
-            "os.environ",
-            {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
-        ), patch.object(
-            sys,
-            "argv",
-            ["greenbone-feed-sync", "--type", "nvt", "--fail-fast"],
+        with (
+            temp_directory() as temp_dir,
+            patch.dict(
+                "os.environ",
+                {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
+            ),
+            patch.object(
+                sys,
+                "argv",
+                ["greenbone-feed-sync", "--type", "nvt", "--fail-fast"],
+            ),
         ):
             ret = await feed_sync(console=console, error_console=console)
             self.assertEqual(ret, 1)
@@ -339,7 +348,7 @@ class FeedSyncTestCase(unittest.IsolatedAsyncioTestCase):
                 [
                     call(
                         url="rsync://feed.community.greenbone.net/community/"
-                        "vulnerability-feed/22.04/vt-data/notus/",
+                        f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/",
                         destination=temp_dir / "notus",
                     ),
                 ]
@@ -353,17 +362,21 @@ class MainFunctionTestCase(unittest.TestCase):
         rsync_mock_instance = rsync_mock.return_value
         console_mock_instance = console_mock.return_value
 
-        with temp_directory() as temp_dir, patch.dict(
-            "os.environ",
-            {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
-        ), patch.object(
-            sys,
-            "argv",
-            [
-                "greenbone-feed-sync",
-                "--type",
-                "nvt",
-            ],
+        with (
+            temp_directory() as temp_dir,
+            patch.dict(
+                "os.environ",
+                {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
+            ),
+            patch.object(
+                sys,
+                "argv",
+                [
+                    "greenbone-feed-sync",
+                    "--type",
+                    "nvt",
+                ],
+            ),
         ):
             with self.assertRaises(SystemExit) as cm:
                 main()
@@ -396,12 +409,12 @@ class MainFunctionTestCase(unittest.TestCase):
                 [
                     call(
                         url="rsync://feed.community.greenbone.net/community/"
-                        "vulnerability-feed/22.04/vt-data/notus/",
+                        f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/",
                         destination=temp_dir / "notus",
                     ),
                     call(
                         url="rsync://feed.community.greenbone.net/community/"
-                        "vulnerability-feed/22.04/vt-data/nasl/",
+                        f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/nasl/",
                         destination=temp_dir / "openvas/plugins",
                     ),
                 ]
@@ -418,13 +431,17 @@ class MainFunctionTestCase(unittest.TestCase):
             "An error"
         )
 
-        with temp_directory() as temp_dir, patch.dict(
-            "os.environ",
-            {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
-        ), patch.object(
-            sys,
-            "argv",
-            ["greenbone-feed-sync", "--type", "nvt", "--fail-fast"],
+        with (
+            temp_directory() as temp_dir,
+            patch.dict(
+                "os.environ",
+                {"GREENBONE_FEED_SYNC_DESTINATION_PREFIX": str(temp_dir)},
+            ),
+            patch.object(
+                sys,
+                "argv",
+                ["greenbone-feed-sync", "--type", "nvt", "--fail-fast"],
+            ),
         ):
             with self.assertRaises(SystemExit) as cm:
                 main()
@@ -457,7 +474,7 @@ class MainFunctionTestCase(unittest.TestCase):
                 [
                     call(
                         url="rsync://feed.community.greenbone.net/community/"
-                        "vulnerability-feed/22.04/vt-data/notus/",
+                        f"vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/",
                         destination=temp_dir / "notus",
                     ),
                 ]
