@@ -1,19 +1,7 @@
-# Copyright (C) 2023 Greenbone AG
+# SPDX-FileCopyrightText: 2023-2024 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # pylint: disable=line-too-long, too-many-lines
 
@@ -49,6 +37,7 @@ from greenbone.feed.sync.config import (
     DEFAULT_SCAP_DATA_PATH,
     DEFAULT_SCAP_DATA_URL_PATH,
     DEFAULT_USER_CONFIG_FILE,
+    DEFAULT_VERSION,
 )
 from greenbone.feed.sync.errors import ConfigFileError
 from greenbone.feed.sync.helper import DEFAULT_FLOCK_WAIT_INTERVAL
@@ -222,9 +211,10 @@ class CliParserTestCase(unittest.TestCase):
     def test_help(self):
         parser = CliParser()
 
-        with redirect_stdout(io.StringIO()) as f, self.assertRaises(
-            SystemExit
-        ) as cm:
+        with (
+            redirect_stdout(io.StringIO()) as f,
+            self.assertRaises(SystemExit) as cm,
+        ):
             parser.parse_arguments(["--help"])
 
         self.assertEqual(cm.exception.code, 0)
@@ -259,7 +249,7 @@ class CliParserTestCase(unittest.TestCase):
         self.assertTrue(args.selftest)
 
     @patch("greenbone.feed.sync.parser.Path")
-    def test_use_default_config_files(self, path_mock: Path):
+    def test_use_default_config_files(self, path_mock):
         path_mock_instance = path_mock.return_value
         path_mock_instance.expanduser.return_value = path_mock_instance
         path_mock_instance.resolve.return_value = path_mock_instance
@@ -460,9 +450,10 @@ class CliParserTestCase(unittest.TestCase):
     def test_other(self):
         parser = CliParser()
 
-        with redirect_stderr(io.StringIO()) as f, self.assertRaises(
-            SystemExit
-        ) as cm:
+        with (
+            redirect_stderr(io.StringIO()) as f,
+            self.assertRaises(SystemExit) as cm,
+        ):
             parser.parse_arguments(["--foo-bar", "10"])
 
         self.assertIn("error: unrecognized arguments: --foo-bar", f.getvalue())
@@ -742,35 +733,35 @@ sed diam nonumy eirmod tempor
             )
             self.assertEqual(
                 args.gvmd_data_url,
-                "ssh://a_user@some.feed.server/enterprise/data-feed/22.04/",
+                f"ssh://a_user@some.feed.server/enterprise/data-feed/{DEFAULT_VERSION}/",
             )
             self.assertEqual(
                 args.port_lists_url,
-                "ssh://a_user@some.feed.server/enterprise/data-feed/22.04/port-lists/",
+                f"ssh://a_user@some.feed.server/enterprise/data-feed/{DEFAULT_VERSION}/port-lists/",
             )
             self.assertEqual(
                 args.report_formats_url,
-                "ssh://a_user@some.feed.server/enterprise/data-feed/22.04/report-formats/",
+                f"ssh://a_user@some.feed.server/enterprise/data-feed/{DEFAULT_VERSION}/report-formats/",
             )
             self.assertEqual(
                 args.scan_configs_url,
-                "ssh://a_user@some.feed.server/enterprise/data-feed/22.04/scan-configs/",
+                f"ssh://a_user@some.feed.server/enterprise/data-feed/{DEFAULT_VERSION}/scan-configs/",
             )
             self.assertEqual(
                 args.notus_url,
-                "ssh://a_user@some.feed.server/enterprise/vulnerability-feed/22.04/vt-data/notus/",
+                f"ssh://a_user@some.feed.server/enterprise/vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/",
             )
             self.assertEqual(
                 args.nasl_url,
-                "ssh://a_user@some.feed.server/enterprise/vulnerability-feed/22.04/vt-data/nasl/",
+                f"ssh://a_user@some.feed.server/enterprise/vulnerability-feed/{DEFAULT_VERSION}/vt-data/nasl/",
             )
             self.assertEqual(
                 args.scap_data_url,
-                "ssh://a_user@some.feed.server/enterprise/vulnerability-feed/22.04/scap-data/",
+                f"ssh://a_user@some.feed.server/enterprise/vulnerability-feed/{DEFAULT_VERSION}/scap-data/",
             )
             self.assertEqual(
                 args.cert_data_url,
-                "ssh://a_user@some.feed.server/enterprise/vulnerability-feed/22.04/cert-data/",
+                f"ssh://a_user@some.feed.server/enterprise/vulnerability-feed/{DEFAULT_VERSION}/cert-data/",
             )
 
     def test_ignore_non_existing_enterprise_feed_key(self):
@@ -784,35 +775,35 @@ sed diam nonumy eirmod tempor
         )
         self.assertEqual(
             args.gvmd_data_url,
-            "rsync://feed.community.greenbone.net/community/data-feed/22.04/",
+            f"rsync://feed.community.greenbone.net/community/data-feed/{DEFAULT_VERSION}/",
         )
         self.assertEqual(
             args.port_lists_url,
-            "rsync://feed.community.greenbone.net/community/data-feed/22.04/port-lists/",
+            f"rsync://feed.community.greenbone.net/community/data-feed/{DEFAULT_VERSION}/port-lists/",
         )
         self.assertEqual(
             args.report_formats_url,
-            "rsync://feed.community.greenbone.net/community/data-feed/22.04/report-formats/",
+            f"rsync://feed.community.greenbone.net/community/data-feed/{DEFAULT_VERSION}/report-formats/",
         )
         self.assertEqual(
             args.scan_configs_url,
-            "rsync://feed.community.greenbone.net/community/data-feed/22.04/scan-configs/",
+            f"rsync://feed.community.greenbone.net/community/data-feed/{DEFAULT_VERSION}/scan-configs/",
         )
         self.assertEqual(
             args.notus_url,
-            "rsync://feed.community.greenbone.net/community/vulnerability-feed/22.04/vt-data/notus/",
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/",
         )
         self.assertEqual(
             args.nasl_url,
-            "rsync://feed.community.greenbone.net/community/vulnerability-feed/22.04/vt-data/nasl/",
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{DEFAULT_VERSION}/vt-data/nasl/",
         )
         self.assertEqual(
             args.scap_data_url,
-            "rsync://feed.community.greenbone.net/community/vulnerability-feed/22.04/scap-data/",
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{DEFAULT_VERSION}/scap-data/",
         )
         self.assertEqual(
             args.cert_data_url,
-            "rsync://feed.community.greenbone.net/community/vulnerability-feed/22.04/cert-data/",
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{DEFAULT_VERSION}/cert-data/",
         )
 
     @patch.object(sys, "argv", ["greenbone-nvt-sync"])
